@@ -16,7 +16,7 @@ from six import PY3
 
 import sys
 
-from robot.utils import html_escape
+from robot.utils import html_escape, setter
 
 from .itemlist import ItemList
 from .modelobject import ModelObject
@@ -28,7 +28,7 @@ class Message(ModelObject):
     The message can be a log message triggered by a keyword, or a warning
     or an error occurred during the test execution.
     """
-    __slots__ = ['message', 'level', 'html', 'timestamp', 'parent']
+    __slots__ = ['message', 'level', 'html', 'timestamp', '_sort_key']
 
     def __init__(self, message='', level='INFO', html=False, timestamp=None,
                  parent=None):
@@ -41,9 +41,16 @@ class Message(ModelObject):
         self.html = html
         #: Timestamp in format ``%Y%m%d %H:%M:%S.%f``.
         self.timestamp = timestamp
+        self._sort_key = -1
         #: The object this message was triggered by.
         self.parent = parent
 
+    @setter
+    def parent(self, parent):
+        if parent and parent is not getattr(self, 'parent', None):
+            self._sort_key = getattr(parent, '_child_sort_key', -1)
+        return parent
+
     @property
     def html_message(self):
         """Returns the message content as HTML."""
@@ -66,3 +73,7 @@ class Messages(ItemList):
     def __init__(self, message_class=Message, parent=None, messages=None):
         ItemList.__init__(self, message_class, {'parent': parent}, messages)
 
+    def __setitem__(self, index, item):
+        old = self[index]
+        ItemList.__setitem__(self, index, item)
+        self[index]._sort_key = old._sort_key
