@@ -187,14 +187,14 @@ class TestSuite(model.TestSuite):
         if not settings:
             settings = RobotSettings(options)
             LOGGER.register_console_logger(**settings.console_logger_config)
-        with STOP_SIGNAL_MONITOR:
-            IMPORTER.reset()
-            pyloggingconf.initialize(settings['LogLevel'])
-            init_global_variables(settings)
-            output = Output(settings)
-            runner = Runner(output, settings)
-            self.visit(runner)
-        output.close(runner.result)
+        with pyloggingconf.robot_handler_enabled(settings.log_level):
+            with STOP_SIGNAL_MONITOR:
+                IMPORTER.reset()
+                init_global_variables(settings)
+                output = Output(settings)
+                runner = Runner(output, settings)
+                self.visit(runner)
+            output.close(runner.result)
         return runner.result
 
 
